//    Coobird's Data Viewing and Selecting Program with Integration (Dvaspi)
//    Copyright (C) 2008 Chris Kroells
//
//    This file is part of Dvaspi.
//
//    Dvaspi is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    Dvapsi is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with Dvaspi.  If not, see <http://www.gnu.org/licenses/>.


package net.coobird.dvaspi;

import java.awt.*;
import javax.swing.*;
import javax.swing.border.*;

/**
 * This class is the CellRenderer for the Data Set list used in DvaspiGui.
 * @author coobird
 *
 */
@SuppressWarnings("serial")
public class DataSetCellRenderer extends JPanel implements ListCellRenderer
{
	private JLabel filenameLabel;
	private JPanel lineColorBox;
	private JPanel pointColorBox;
	private JPanel pointSelectedColorBox;
	private JPanel labelColorBox;
	
	public static final int MODE_LINECOLOR_ONLY = 0;
	public static final int MODE_ALLCOLORS = 1;
	
	private int mode;
	
	
	/**
	 * Default constructor.
	 * This constructor calls the DataSetCellRenderer(int)
	 * constructor with the option to show only the line color box.
	 */
	public DataSetCellRenderer()
	{
		this(MODE_LINECOLOR_ONLY);
	}
	
	/**
	 * Constructor with option to select which color boxes are displayed.
	 * @param mode The color box display mode. (See the constants.) 
	 */
	public DataSetCellRenderer(int mode)
	{
		this.mode = mode;
		this.setLayout(new BorderLayout());
		filenameLabel = new JLabel("no name");
		
		// Creates the color box for the line color
		JPanel colorPanel = new JPanel();
		lineColorBox = new JPanel();
		lineColorBox.setBackground(Color.blue);
		lineColorBox.setOpaque(true);
		lineColorBox.setBorder(BorderFactory.createCompoundBorder(
				BorderFactory.createLineBorder(Color.black, 1),
				BorderFactory.createEmptyBorder(2,2,2,2)));
		colorPanel.add(lineColorBox);
		
		if (mode == MODE_ALLCOLORS)
		{
			pointColorBox = new JPanel();
			pointColorBox.setBackground(Color.black);
			pointColorBox.setOpaque(true);
			pointSelectedColorBox = new JPanel();
			pointSelectedColorBox.setBackground(Color.black);
			pointSelectedColorBox.setOpaque(true);
			labelColorBox = new JPanel();
			labelColorBox.setBackground(Color.black);
			labelColorBox.setOpaque(true);

			pointColorBox.setBorder(BorderFactory.createCompoundBorder(
				BorderFactory.createLineBorder(Color.black, 1),
				BorderFactory.createEmptyBorder(2,2,2,2)));
			pointSelectedColorBox.setBorder(BorderFactory.createCompoundBorder(
				BorderFactory.createLineBorder(Color.black, 1),
				BorderFactory.createEmptyBorder(2,2,2,2)));
			labelColorBox.setBorder(BorderFactory.createCompoundBorder(
				BorderFactory.createLineBorder(Color.black, 1),
				BorderFactory.createEmptyBorder(2,2,2,2)));

			colorPanel.add(pointColorBox);
			colorPanel.add(pointSelectedColorBox);
			colorPanel.add(labelColorBox);
		}
		
		colorPanel.setOpaque(false);

		this.setBorder(BorderFactory.createEmptyBorder(5,5,5,5));
		
		filenameLabel.setBorder(new EmptyBorder(0,5,0,0));
		
		this.add(colorPanel, BorderLayout.WEST);
		this.add(filenameLabel, BorderLayout.CENTER);
	}
	

	/**
	 * Returns a CellRenderer for the DataSet.
	 * @return The CellRenderer for the DataSet 
	 */
	public Component getListCellRendererComponent(JList list, Object obj,
			int index, boolean isSelected, boolean cellHasFocus)
	{
		filenameLabel.setText(((DataSet)obj).getName());
		lineColorBox.setBackground(((DataSet)obj).lineColor);
		
		if (mode == MODE_ALLCOLORS)
		{
			pointColorBox.setBackground(((DataSet)obj).pointColor);
			pointSelectedColorBox.setBackground(((DataSet)obj).pointSelectedColor);
			labelColorBox.setBackground(((DataSet)obj).labelColor);
		}
		
		if (isSelected)
		{
			this.setBackground(list.getSelectionBackground());
			this.setForeground(list.getSelectionForeground());
			filenameLabel.setForeground(list.getSelectionForeground());
		}
		else
		{
			this.setBackground(list.getBackground());
			this.setForeground(list.getForeground());
			filenameLabel.setForeground(list.getForeground());
		}
		this.setOpaque(true);
		
		return this;
	}
}