//    Coobird's Data Viewing and Selecting Program with Integration (Dvaspi)
//    Copyright (C) 2008 Chris Kroells
//
//    This file is part of Dvaspi.
//
//    Dvaspi is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    Dvapsi is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with Dvaspi.  If not, see <http://www.gnu.org/licenses/>.


package net.coobird.dvaspi;

import javax.swing.*;
import java.awt.*;
import java.awt.event.*;

/**
 * Console for the DvaspiGui
 * @author coobird
 */
@SuppressWarnings("serial")
public class DvaspiConsole extends JPanel implements MouseListener, ActionListener
{
	JTextArea ta;
	JScrollPane sp;
	
	JPopupMenu popupMenu;
	JMenuItem cutMenuItem;
	JMenuItem copyMenuItem;
	JMenuItem pasteMenuItem;
	JMenuItem clearMenuItem;
		
	public DvaspiConsole()
	{
		this.setLayout(new BorderLayout());
		
		ta = new JTextArea();
		sp = new JScrollPane(ta);
		
		this.add(sp, BorderLayout.CENTER);
		
		popupMenu = new JPopupMenu();
		cutMenuItem = new JMenuItem("Cut");
		copyMenuItem = new JMenuItem("Copy");
		pasteMenuItem = new JMenuItem("Paste");
		clearMenuItem = new JMenuItem("Clear console");
		popupMenu.add(cutMenuItem);
		popupMenu.add(copyMenuItem);
		popupMenu.add(pasteMenuItem);
		popupMenu.addSeparator();
		popupMenu.add(clearMenuItem);
		cutMenuItem.addActionListener(this);
		copyMenuItem.addActionListener(this);
		pasteMenuItem.addActionListener(this);
		clearMenuItem.addActionListener(this);
		
		ta.add(popupMenu);

		ta.addMouseListener(this);
	}
	
	public void append(String s)
	{
		ta.append(s);
	}
	
	public void appendln(String s)
	{
		ta.append(s + "\n");
	}
	
	private void showPopup(MouseEvent e)
	{
		if (e.isPopupTrigger())
		{
			boolean selected = (ta.getSelectionStart() != ta.getSelectionEnd());
			copyMenuItem.setEnabled(selected);
			cutMenuItem.setEnabled(selected);
			popupMenu.show(ta, e.getX(), e.getY());
		}
	}

	public void mouseClicked(MouseEvent arg0)
	{
	}

	public void mousePressed(MouseEvent arg0)
	{
		showPopup(arg0);
	}

	public void mouseReleased(MouseEvent arg0)
	{
		showPopup(arg0);
	}

	public void mouseEntered(MouseEvent arg0) {}
	public void mouseExited(MouseEvent arg0) {}

	public void actionPerformed(ActionEvent e)
	{
		Object source = e.getSource();
		
		if (ta.getSelectionStart() != ta.getSelectionEnd())
		{
			if (source == copyMenuItem)
			{
				ta.copy();
			}
			else if (source == cutMenuItem)
			{
				ta.cut();
			}
		}
		else if (source == pasteMenuItem)
		{
			ta.paste();
		}
		else if (source == clearMenuItem)
		{
			ta.setText("");
		}
	}
}
