//    Coobird's Data Viewing and Selecting Program with Integration (Dvaspi)
//    Copyright (C) 2008 Chris Kroells
//
//    This file is part of Dvaspi.
//
//    Dvaspi is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    Dvapsi is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with Dvaspi.  If not, see <http://www.gnu.org/licenses/>.


package net.coobird.dvaspi;

import java.awt.*;
import javax.swing.*;

/**
 * Status bar that is added to the graphical interface which
 * displays the current mode, message and location.
 * @author coobird
 */
@SuppressWarnings("serial")
public class DvaspiStatusBar extends JPanel
{
	private JLabel modeLabel;
	private JLabel messageLabel;
	private JLabel locationLabel;

	public DvaspiStatusBar()
	{
		super();

		GridBagLayout gb = new GridBagLayout();
		GridBagConstraints c = new GridBagConstraints();
		
		this.setLayout(gb);
		
		modeLabel = new JLabel("None");
		messageLabel = new JLabel(" ");
		locationLabel = new JLabel(" ");
		
		setBorder(BorderFactory.createCompoundBorder(
				BorderFactory.createEtchedBorder(),
				BorderFactory.createEmptyBorder(2, 2, 2, 2)));
		
		modeLabel.setBorder(BorderFactory.createCompoundBorder(
				BorderFactory.createEtchedBorder(),
				BorderFactory.createEmptyBorder(2, 2, 2, 2)));
		messageLabel.setBorder(BorderFactory.createCompoundBorder(
				BorderFactory.createEtchedBorder(),
				BorderFactory.createEmptyBorder(2, 2, 2, 2)));
		locationLabel.setBorder(BorderFactory.createCompoundBorder(
				BorderFactory.createEtchedBorder(),
				BorderFactory.createEmptyBorder(2, 2, 2, 2)));
				
		add(modeLabel);
		add(messageLabel);
		add(locationLabel);
		
		c.weightx = 1;
		c.anchor = GridBagConstraints.WEST;
		c.fill = GridBagConstraints.HORIZONTAL;
		gb.setConstraints(modeLabel, c);
		c.weightx = 4;
		c.anchor = GridBagConstraints.CENTER;
		gb.setConstraints(messageLabel, c);
		c.weightx = 2;
		c.anchor = GridBagConstraints.EAST;
		gb.setConstraints(locationLabel, c);
	}
		
	/**
	 * Overrides the JPanel.doLayout().
	 */
	public void doLayout()
	{
		super.doLayout();
		
		modeLabel.setPreferredSize(modeLabel.getSize());
		messageLabel.setPreferredSize(messageLabel.getSize());
		locationLabel.setPreferredSize(locationLabel.getSize());
	}
	
	/**
	 * Sets the mode label.
	 * @param s The text to set the mode label to.
	 */
	public void setMode(String s)
	{
		if (s.equals(""))
			modeLabel.setText(" ");
		else
			modeLabel.setText(s);
	}

	/**
	 * Sets the message label to provided text.
	 * @param s The text to set the message label to.
	 */
	public void setMessage(String s)
	{
		if (s.equals(""))
			messageLabel.setText(" ");
		else
			messageLabel.setText(s);
	}
	
	/**
	 * Sets the location label to provided text.
	 * @param s The text to set the location label to.
	 */
	public void setLocation(String s)
	{
		if (s.equals(""))
			locationLabel.setText(" ");
		else
			locationLabel.setText(s);
	}
}